Funcionalidades
===============

* `Usando depuradores <debuggers.rst>`_
* `Usando pacotes de terceiros <packages.rst>`_
* `Encaixando janelas do usuário <dock.rst>`_
* `Suporte especial para programas de Tartaruga <turtle.rst>`_
* `Especificando argumentos de programa <program_arguments.rst>`_
* `Modo simples e modo especialista <modes.rst>`_
* `Shell <shell.rst>`_
* `Plotador <plotter.rst>`_
* `Assistente <assistant.rst>`_
* `Birdseye <birdseye.rst>`_
* `Desenvolvimento Web com Flask <flask.rst>`_

Tópicos gerais
==============
* `Lidando com erros <errors.rst>`_
* `Conselhos gerais sobre depuração <debugging.rst>`_

Online
======
Há mais informações disponíveis no wiki do Thonny: https://github.com/thonny/thonny/wiki.

